//>>built
define("dojo/nls/pmbdojo_he-il",{"dijit/form/nls/validate":{invalidMessage:"\u05d4\u05e2\u05e8\u05da \u05e9\u05e6\u05d5\u05d9\u05df \u05d0\u05d9\u05e0\u05d5 \u05d7\u05d5\u05e7\u05d9.",missingMessage:"\u05d6\u05d4\u05d5 \u05e2\u05e8\u05da \u05d3\u05e8\u05d5\u05e9.",rangeMessage:"\u05d4\u05e2\u05e8\u05da \u05de\u05d7\u05d5\u05e5 \u05dc\u05d8\u05d5\u05d5\u05d7.",_localized:{}},"dojo/cldr/nls/number":{scientificFormat:"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]",infinity:"\u221e",superscriptingExponent:"\u00d7",
list:";",percentSign:"%",minusSign:"\u200e-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000T","currencySpacing-afterCurrency-insertBetween":"\u00a0",nan:"NaN",plusSign:"\u200e+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]",currencyFormat:"#,##0.00\u00a0\u00a4",perMille:"\u2030",group:",",percentFormat:"#,##0%","decimalFormat-long":"\u200f000 \u05d8\u05e8\u05d9\u05dc\u05d9\u05d5\u05df",
decimalFormat:"#,##0.###",decimal:".","currencySpacing-beforeCurrency-insertBetween":"\u00a0",exponential:"E",_localized:{}},"dijit/form/nls/ComboBox":{previousMessage:"\u05d4\u05d0\u05e4\u05e9\u05e8\u05d5\u05d9\u05d5\u05ea \u05d4\u05e7\u05d5\u05d3\u05de\u05d5\u05ea",nextMessage:"\u05d0\u05e4\u05e9\u05e8\u05d5\u05d9\u05d5\u05ea \u05e0\u05d5\u05e1\u05e4\u05d5\u05ea",_localized:{}},"dijit/nls/loading":{loadingState:"\u05d8\u05e2\u05d9\u05e0\u05d4...\u200f",errorState:"\u05d0\u05d9\u05e8\u05e2\u05d4 \u05e9\u05d2\u05d9\u05d0\u05d4",
_localized:{}},"dijit/nls/common":{buttonOk:"\u05d0\u05d9\u05e9\u05d5\u05e8",buttonCancel:"\u05d1\u05d9\u05d8\u05d5\u05dc",buttonSave:"\u05e9\u05de\u05d9\u05e8\u05d4",itemClose:"\u05e1\u05d2\u05d9\u05e8\u05d4",_localized:{}},"dijit/_editor/nls/commands":{bold:"\u05de\u05d5\u05d3\u05d2\u05e9",copy:"\u05d4\u05e2\u05ea\u05e7\u05d4",cut:"\u05d2\u05d6\u05d9\u05e8\u05d4","delete":"\u05de\u05d7\u05d9\u05e7\u05d4",indent:"\u05d4\u05d2\u05d3\u05dc\u05ea \u05db\u05e0\u05d9\u05e1\u05d4",insertHorizontalRule:"\u05e7\u05d5 \u05d0\u05d5\u05e4\u05e7\u05d9",
insertOrderedList:"\u05e8\u05e9\u05d9\u05de\u05d4 \u05de\u05de\u05e1\u05d5\u05e4\u05e8\u05ea",insertUnorderedList:"\u05e8\u05e9\u05d9\u05de\u05d4 \u05e2\u05dd \u05ea\u05d1\u05dc\u05d9\u05d8\u05d9\u05dd",italic:"\u05e0\u05d8\u05d5\u05d9",justifyCenter:"\u05d9\u05d9\u05e9\u05d5\u05e8 \u05dc\u05de\u05e8\u05db\u05d6",justifyFull:"\u05d9\u05d9\u05e9\u05d5\u05e8 \u05d3\u05d5-\u05e6\u05d3\u05d3\u05d9",justifyLeft:"\u05d9\u05d9\u05e9\u05d5\u05e8 \u05dc\u05d9\u05de\u05d9\u05df",justifyRight:"\u05d9\u05d9\u05e9\u05d5\u05e8 \u05dc\u05e9\u05de\u05d0\u05dc",
outdent:"\u05d4\u05e7\u05d8\u05e0\u05ea \u05db\u05e0\u05d9\u05e1\u05d4",paste:"\u05d4\u05d3\u05d1\u05e7\u05d4",redo:"\u05e9\u05d7\u05d6\u05d5\u05e8 \u05e4\u05e2\u05d5\u05dc\u05d4",removeFormat:"\u05e1\u05d9\u05dc\u05d5\u05e7 \u05e2\u05d9\u05e6\u05d5\u05d1",selectAll:"\u05d1\u05d7\u05d9\u05e8\u05ea \u05d4\u05db\u05dc",strikethrough:"\u05e7\u05d5 \u05d7\u05d5\u05e6\u05d4",subscript:"\u05db\u05ea\u05d1 \u05ea\u05d7\u05ea\u05d9",superscript:"\u05db\u05ea\u05d1 \u05e2\u05d9\u05dc\u05d9",underline:"\u05e7\u05d5 \u05ea\u05d7\u05ea\u05d5\u05df",
undo:"\u05d1\u05d9\u05d8\u05d5\u05dc \u05e4\u05e2\u05d5\u05dc\u05d4",unlink:"\u05e1\u05d9\u05dc\u05d5\u05e7 \u05d4\u05e7\u05d9\u05e9\u05d5\u05e8",createLink:"\u05d9\u05e6\u05d9\u05e8\u05ea \u05e7\u05d9\u05e9\u05d5\u05e8",toggleDir:"\u05de\u05d9\u05ea\u05d5\u05d2 \u05db\u05d9\u05d5\u05d5\u05df",insertImage:"\u05d4\u05d5\u05e1\u05e4\u05ea \u05ea\u05de\u05d5\u05e0\u05d4",insertTable:"\u05d4\u05d5\u05e1\u05e4\u05ea/\u05e2\u05e8\u05d9\u05db\u05ea \u05d8\u05d1\u05dc\u05d4",toggleTableBorder:"\u05de\u05d9\u05ea\u05d5\u05d2 \u05d2\u05d1\u05d5\u05dc \u05d8\u05d1\u05dc\u05d4",
deleteTable:"\u05de\u05d7\u05d9\u05e7\u05ea \u05d8\u05d1\u05dc\u05d4",tableProp:"\u05ea\u05db\u05d5\u05e0\u05ea \u05d8\u05d1\u05dc\u05d4",htmlToggle:"\u05de\u05e7\u05d5\u05e8 HTML",foreColor:"\u05e6\u05d1\u05e2 \u05d7\u05d6\u05d9\u05ea",hiliteColor:"\u05e6\u05d1\u05e2 \u05e8\u05e7\u05e2",plainFormatBlock:"\u05e1\u05d2\u05e0\u05d5\u05df \u05e4\u05d9\u05e1\u05e7\u05d4",formatBlock:"\u05e1\u05d2\u05e0\u05d5\u05df \u05e4\u05d9\u05e1\u05e7\u05d4",fontSize:"\u05d2\u05d5\u05d3\u05dc \u05d2\u05d5\u05e4\u05df",
fontName:"\u05e9\u05dd \u05d2\u05d5\u05e4\u05df",tabIndent:"\u05db\u05e0\u05d9\u05e1\u05ea \u05d8\u05d0\u05d1",fullScreen:"\u05de\u05d9\u05ea\u05d5\u05d2 \u05de\u05e1\u05da \u05de\u05dc\u05d0",viewSource:"\u05d4\u05e6\u05d2\u05ea \u05de\u05e7\u05d5\u05e8 HTML",print:"\u05d4\u05d3\u05e4\u05e1\u05d4",newPage:"\u05d3\u05e3 \u05d7\u05d3\u05e9",systemShortcut:'\u05d4\u05e4\u05e2\u05d5\u05dc\u05d4 "${0}" \u05d6\u05de\u05d9\u05e0\u05d4 \u05d1\u05d3\u05e4\u05d3\u05e4\u05df \u05e8\u05e7 \u05d1\u05d0\u05de\u05e6\u05e2\u05d5\u05ea \u05e7\u05d9\u05e6\u05d5\u05e8 \u05d3\u05e8\u05da \u05d1\u05de\u05e7\u05dc\u05d3\u05ea.  \u05d4\u05e9\u05ea\u05de\u05e9\u05d5 \u05d1\u05e7\u05d9\u05e6\u05d5\u05e8 ${1}.',
ctrlKey:"ctrl+${0}\u200e",appleKey:"\u2318${0}\u200e",_localized:{}},"dijit/_editor/nls/FontChoice":{1:"\u05e7\u05d8\u05df \u05d1\u05d9\u05d5\u05ea",2:"\u05e7\u05d8\u05df \u05de\u05d0\u05d5\u05d3",3:"\u05e7\u05d8\u05df",4:"\u05d1\u05d9\u05e0\u05d5\u05e0\u05d9",5:"\u05d2\u05d3\u05d5\u05dc",6:"\u05d2\u05d3\u05d5\u05dc \u05de\u05d0\u05d5\u05d3",7:"\u05d2\u05d3\u05d5\u05dc \u05d1\u05d9\u05d5\u05ea\u05e8",fontSize:"\u05d2\u05d5\u05d3\u05dc",fontName:"\u05d2\u05d5\u05e4\u05df",formatBlock:"\u05e2\u05d9\u05e6\u05d5\u05d1",
serif:"serif","sans-serif":"sans-serif",monospace:"monospace",cursive:"cursive",fantasy:"fantasy",noFormat:"\u05dc\u05dc\u05d0 ",p:"\u05e4\u05d9\u05e1\u05e7\u05d4",h1:"\u05db\u05d5\u05ea\u05e8\u05ea",h2:"\u05ea\u05ea-\u05db\u05d5\u05ea\u05e8\u05ea",h3:"\u05ea\u05ea-\u05ea\u05ea-\u05db\u05d5\u05ea\u05e8\u05ea",pre:"\u05de\u05e2\u05d5\u05e6\u05d1 \u05de\u05e8\u05d0\u05e9",_localized:{}},"dojox/editor/plugins/nls/latinEntities":{iexcl:"inverted exclamation mark",cent:"cent sign",pound:"pound sign",curren:"currency sign",
yen:"yen sign\nyuan sign",brvbar:"broken bar\nbroken vertical bar",sect:"section sign",uml:"diaeresis\nspacing diaeresis",copy:"copyright sign",ordf:"feminine ordinal indicator",laquo:"left-pointing double angle quotation mark\nleft pointing guillemet",not:"not sign",shy:"soft hyphen\ndiscretionary hyphen",reg:"registered sign\nregistered trade mark sign",macr:"macron\nspacing macron\noverline\nAPL overbar",deg:"degree sign",plusmn:"plus-minus sign\nplus-or-minus sign",sup2:"superscript two\nsuperscript digit two\nsquared",
sup3:"superscript three\nsuperscript digit three\ncubed",acute:"acute accent\nspacing acute",micro:"micro sign",para:"pilcrow sign\nparagraph sign",middot:"middle dot\nGeorgian comma\nGreek middle dot",cedil:"cedilla\nspacing cedilla",sup1:"superscript one\nsuperscript digit one",ordm:"masculine ordinal indicator",raquo:"right-pointing double angle quotation mark\nright pointing guillemet",frac14:"vulgar fraction one quarter\nfraction one quarter",frac12:"vulgar fraction one half\nfraction one half",
frac34:"vulgar fraction three quarters\nfraction three quarters",iquest:"inverted question mark\nturned question mark",Agrave:"Latin capital letter A with grave\nLatin capital letter A grave",Aacute:"Latin capital letter A with acute",Acirc:"Latin capital letter A with circumflex",Atilde:"Latin capital letter A with tilde",Auml:"Latin capital letter A with diaeresis",Aring:"Latin capital letter A with ring above\nLatin capital letter A ring",AElig:"Latin capital letter AE\nLatin capital ligature AE",
Ccedil:"Latin capital letter C with cedilla",Egrave:"Latin capital letter E with grave",Eacute:"Latin capital letter E with acute",Ecirc:"Latin capital letter E with circumflex",Euml:"Latin capital letter E with diaeresis",Igrave:"Latin capital letter I with grave",Iacute:"Latin capital letter I with acute",Icirc:"Latin capital letter I with circumflex",Iuml:"Latin capital letter I with diaeresis",ETH:"Latin capital letter ETH",Ntilde:"Latin capital letter N with tilde",Ograve:"Latin capital letter O with grave",
Oacute:"Latin capital letter O with acute",Ocirc:"Latin capital letter O with circumflex",Otilde:"Latin capital letter O with tilde",Ouml:"Latin capital letter O with diaeresis",times:"multiplication sign",Oslash:"Latin capital letter O with stroke\nLatin capital letter O slash",Ugrave:"Latin capital letter U with grave",Uacute:"Latin capital letter U with acute",Ucirc:"Latin capital letter U with circumflex",Uuml:"Latin capital letter U with diaeresis",Yacute:"Latin capital letter Y with acute",
THORN:"Latin capital letter THORN",szlig:"Latin small letter sharp s\ness-zed",agrave:"Latin small letter a with grave\nLatin small letter a grave",aacute:"Latin small letter a with acute",acirc:"Latin small letter a with circumflex",atilde:"Latin small letter a with tilde",auml:"Latin small letter a with diaeresis",aring:"Latin small letter a with ring above\nLatin small letter a ring",aelig:"Latin small letter ae\nLatin small ligature ae",ccedil:"Latin small letter c with cedilla",egrave:"Latin small letter e with grave",
eacute:"Latin small letter e with acute",ecirc:"Latin small letter e with circumflex",euml:"Latin small letter e with diaeresis",igrave:"Latin small letter i with grave",iacute:"Latin small letter i with acute",icirc:"Latin small letter i with circumflex",iuml:"Latin small letter i with diaeresis",eth:"Latin small letter eth",ntilde:"Latin small letter n with tilde",ograve:"Latin small letter o with grave",oacute:"Latin small letter o with acute",ocirc:"Latin small letter o with circumflex",otilde:"Latin small letter o with tilde",
ouml:"Latin small letter o with diaeresis",divide:"division sign",oslash:"Latin small letter o with stroke\nLatin small letter o slash",ugrave:"Latin small letter u with grave",uacute:"Latin small letter u with acute",ucirc:"Latin small letter u with circumflex",uuml:"Latin small letter u with diaeresis",yacute:"Latin small letter y with acute",thorn:"Latin small letter thorn",yuml:"Latin small letter y with diaeresis",fnof:"Latin small f with hook\nfunction\nflorin",Alpha:"Greek capital letter alpha",
Beta:"Greek capital letter beta",Gamma:"Greek capital letter gamma",Delta:"Greek capital letter delta",Epsilon:"Greek capital letter epsilon",Zeta:"Greek capital letter zeta",Eta:"Greek capital letter eta",Theta:"Greek capital letter theta",Iota:"Greek capital letter iota",Kappa:"Greek capital letter kappa",Lambda:"Greek capital letter lambda",Mu:"Greek capital letter mu",Nu:"Greek capital letter nu",Xi:"Greek capital letter xi",Omicron:"Greek capital letter omicron",Pi:"Greek capital letter pi",
Rho:"Greek capital letter rho",Sigma:"Greek capital letter sigma",Tau:"Greek capital letter tau",Upsilon:"Greek capital letter upsilon",Phi:"Greek capital letter phi",Chi:"Greek capital letter chi",Psi:"Greek capital letter psi",Omega:"Greek capital letter omega",alpha:"Greek small letter alpha",beta:"Greek small letter beta",gamma:"Greek small letter gamma",delta:"Greek small letter delta",epsilon:"Greek small letter epsilon",zeta:"Greek small letter zeta",eta:"Greek small letter eta",theta:"Greek small letter theta",
iota:"Greek small letter iota",kappa:"Greek small letter kappa",lambda:"Greek small letter lambda",mu:"Greek small letter mu",nu:"Greek small letter nu",xi:"Greek small letter xi",omicron:"Greek small letter omicron",pi:"Greek small letter pi",rho:"Greek small letter rho",sigmaf:"Greek small letter final sigma",sigma:"Greek small letter sigma",tau:"Greek small letter tau",upsilon:"Greek small letter upsilon",phi:"Greek small letter phi",chi:"Greek small letter chi",psi:"Greek small letter psi",omega:"Greek small letter omega",
thetasym:"Greek small letter theta symbol",upsih:"Greek upsilon with hook symbol",piv:"Greek pi symbol",bull:"bullet\nblack small circle",hellip:"horizontal ellipsis\nthree dot leader",prime:"prime\nminutes\nfeet",Prime:"double prime\nseconds\ninches",oline:"overline\nspacing overscore",frasl:"fraction slash",weierp:"script capital P\npower set\nWeierstrass p",image:"blackletter capital I\nimaginary part",real:"blackletter capital R\nreal part symbol",trade:"trade mark sign",alefsym:"alef symbol\nfirst transfinite cardinal",
larr:"leftwards arrow",uarr:"upwards arrow",rarr:"rightwards arrow",darr:"downwards arrow",harr:"left right arrow",crarr:"downwards arrow with corner leftwards\ncarriage return",lArr:"leftwards double arrow",uArr:"upwards double arrow",rArr:"rightwards double arrow",dArr:"downwards double arrow",hArr:"left right double arrow",forall:"for all",part:"partial differential",exist:"there exists",empty:"empty set\nnull set\ndiameter",nabla:"nabla\nbackward difference",isin:"element of",notin:"not an element of",
ni:"contains as member",prod:"n-ary product\nproduct sign",sum:"n-ary sumation",minus:"minus sign",lowast:"asterisk operator",radic:"square root\nradical sign",prop:"proportional to",infin:"infinity",ang:"angle",and:"logical and\nwedge",or:"logical or\nvee",cap:"intersection\ncap",cup:"union\ncup","int":"integral",there4:"therefore",sim:"tilde operator\nvaries with\nsimilar to",cong:"approximately equal to",asymp:"almost equal to\nasymptotic to",ne:"not equal to",equiv:"identical to",le:"less-than or equal to",
ge:"greater-than or equal to",sub:"subset of",sup:"superset of",nsub:"not a subset of",sube:"subset of or equal to",supe:"superset of or equal to",oplus:"circled plus\ndirect sum",otimes:"circled times\nvector product",perp:"up tack\northogonal to\nperpendicular",sdot:"dot operator",lceil:"left ceiling\nAPL upstile",rceil:"right ceiling",lfloor:"left floor\nAPL downstile",rfloor:"right floor",lang:"left-pointing angle bracket",rang:"right-pointing angle bracket",loz:"lozenge",spades:"black spade suit",
clubs:"black club suit\nshamrock",hearts:"black heart suit\nvalentine",diams:"black diamond suit",OElig:"Latin capital ligature OE",oelig:"Latin small ligature oe",Scaron:"Latin capital letter S with caron",scaron:"Latin small letter s with caron",Yuml:"Latin capital letter Y with diaeresis",circ:"modifier letter circumflex accent",tilde:"small tilde",ensp:"en space",emsp:"em space",thinsp:"thin space",zwnj:"zero width non-joiner",zwj:"zero width joiner",lrm:"left-to-right mark",rlm:"right-to-left mark",
ndash:"en dash",mdash:"em dash",lsquo:"left single quotation mark",rsquo:"right single quotation mark",sbquo:"single low-9 quotation mark",ldquo:"left double quotation mark",rdquo:"right double quotation mark",bdquo:"double low-9 quotation mark",dagger:"dagger",Dagger:"double dagger",permil:"per mille sign",lsaquo:"single left-pointing angle quotation mark",rsaquo:"single right-pointing angle quotation mark",euro:"euro sign",_localized:{}},"dojox/editor/plugins/nls/InsertEntity":{insertEntity:"\u05d4\u05d5\u05e1\u05e4\u05ea \u05e1\u05de\u05dc ",
_localized:{}},"dojo/nls/colors":{aliceblue:"\u05db\u05d7\u05d5\u05dc \u05e4\u05dc\u05d3\u05d4",antiquewhite:"\u05dc\u05d1\u05df \u05e2\u05ea\u05d9\u05e7",aqua:"\u05d0\u05e7\u05d5\u05d5\u05d4",aquamarine:"\u05d0\u05e7\u05d5\u05d5\u05de\u05d0\u05e8\u05d9\u05df",azure:"\u05ea\u05db\u05dc\u05ea \u05e2\u05d6",beige:"\u05d1\u05d6'",bisque:"\u05dc\u05d1\u05df \u05e9\u05e7\u05d3",black:"\u05e9\u05d7\u05d5\u05e8",blanchedalmond:"\u05e9\u05e7\u05d3",blue:"\u05db\u05d7\u05d5\u05dc",blueviolet:"\u05db\u05d7\u05d5\u05dc-\u05e1\u05d2\u05d5\u05dc",
brown:"\u05d7\u05d5\u05dd",burlywood:"\u05d7\u05d5\u05dd \u05d3\u05d4\u05d5\u05d9",cadetblue:"\u05db\u05d7\u05d5\u05dc \u05d9\u05dd",chartreuse:"\u05d9\u05e8\u05d5\u05e7-\u05e6\u05d4\u05d5\u05d1",chocolate:"\u05e9\u05d5\u05e7\u05d5\u05dc\u05d3",coral:"\u05d0\u05dc\u05de\u05d5\u05d2",cornflowerblue:"\u05db\u05d7\u05d5\u05dc \u05d3\u05e8\u05d3\u05e8",cornsilk:"\u05e6\u05d4\u05d1\u05d4\u05d1",crimson:"\u05d0\u05e8\u05d2\u05de\u05df",cyan:"\u05d8\u05d5\u05e8\u05e7\u05d9\u05d6",darkblue:"\u05db\u05d7\u05d5\u05dc \u05db\u05d4\u05d4",
darkcyan:"\u05d8\u05d5\u05e8\u05e7\u05d9\u05d6 \u05db\u05d4\u05d4",darkgoldenrod:"\u05d6\u05d4\u05d5\u05d1 \u05db\u05d4\u05d4",darkgray:"\u05d0\u05e4\u05d5\u05e8 \u05db\u05d4\u05d4",darkgreen:"\u05d9\u05e8\u05d5\u05e7 \u05db\u05d4\u05d4",darkgrey:"\u05d0\u05e4\u05d5\u05e8 \u05db\u05d4\u05d4",darkkhaki:"\u05d7\u05d0\u05e7\u05d9 \u05db\u05d4\u05d4",darkmagenta:"\u05d1\u05d5\u05e8\u05d3\u05d5 \u05db\u05d4\u05d4",darkolivegreen:"\u05d9\u05e8\u05d5\u05e7 \u05d6\u05d9\u05ea \u05db\u05d4\u05d4",darkorange:"\u05db\u05ea\u05d5\u05dd \u05db\u05d4\u05d4",
darkorchid:"\u05e1\u05d7\u05dc\u05d1 \u05db\u05d4\u05d4",darkred:"\u05d0\u05d3\u05d5\u05dd \u05db\u05d4\u05d4",darksalmon:"\u05e1\u05dc\u05de\u05d5\u05df \u05db\u05d4\u05d4",darkseagreen:"\u05d9\u05e8\u05d5\u05e7 \u05d9\u05dd \u05db\u05d4\u05d4",darkslateblue:"\u05db\u05d7\u05d5\u05dc \u05e6\u05e4\u05d7\u05d4 \u05db\u05d4\u05d4",darkslategray:"\u05d0\u05e4\u05d5\u05e8 \u05e6\u05e4\u05d7\u05d4 \u05db\u05d4\u05d4",darkslategrey:"\u05d0\u05e4\u05d5\u05e8 \u05e6\u05e4\u05d7\u05d4 \u05db\u05d4\u05d4",
darkturquoise:"\u05d8\u05d5\u05e8\u05e7\u05d9\u05d6 \u05db\u05d4\u05d4",darkviolet:"\u05e1\u05d2\u05d5\u05dc \u05db\u05d4\u05d4",deeppink:"\u05d5\u05e8\u05d5\u05d3 \u05e2\u05de\u05d5\u05e7",deepskyblue:"\u05db\u05d7\u05d5\u05dc \u05e9\u05de\u05d9\u05d9\u05dd \u05e2\u05de\u05d5\u05e7",dimgray:"\u05d0\u05e4\u05d5\u05e8 \u05e2\u05de\u05d5\u05dd",dimgrey:"\u05d0\u05e4\u05d5\u05e8 \u05e2\u05de\u05d5\u05dd",dodgerblue:"\u05db\u05d7\u05d5\u05dc",firebrick:"\u05dc\u05d1\u05e0\u05d4 \u05e9\u05e8\u05d5\u05e4\u05d4",
floralwhite:"\u05dc\u05d1\u05df \u05e4\u05e8\u05d7\u05d5\u05e0\u05d9",forestgreen:"\u05d9\u05e8\u05d5\u05e7 \u05d9\u05e2\u05e8",fuchsia:"\u05d5\u05e8\u05d5\u05d3 \u05d1\u05d4\u05d9\u05e8",gainsboro:"\u05d2\u05d9\u05d9\u05e0\u05e1\u05d1\u05d5\u05e8\u05d5",ghostwhite:"\u05dc\u05d1\u05df \u05e8\u05e4\u05d0\u05d9\u05dd",gold:"\u05d6\u05d4\u05d1",goldenrod:"\u05d6\u05d4\u05d5\u05d1",gray:"\u05d0\u05e4\u05d5\u05e8",green:"\u05d9\u05e8\u05d5\u05e7",greenyellow:"\u05d9\u05e8\u05d5\u05e7-\u05e6\u05d4\u05d5\u05d1",
grey:"\u05d0\u05e4\u05d5\u05e8",honeydew:"\u05d9\u05e8\u05e7\u05e8\u05e7",hotpink:"\u05d5\u05e8\u05d5\u05d3 \u05dc\u05d5\u05d4\u05d8",indianred:"\u05d0\u05d3\u05d5\u05dd \u05d3\u05d4\u05d5\u05d9",indigo:"\u05d0\u05d9\u05e0\u05d3\u05d9\u05d2\u05d5",ivory:"\u05e9\u05e0\u05d4\u05d1",khaki:"\u05d7\u05d0\u05e7\u05d9",lavender:"\u05dc\u05d1\u05e0\u05d3\u05e8",lavenderblush:"\u05e1\u05d5\u05de\u05e7 \u05dc\u05d1\u05e0\u05d3\u05e8",lawngreen:"\u05d9\u05e8\u05d5\u05e7 \u05d3\u05e9\u05d0",lemonchiffon:"\u05d9\u05e8\u05d5\u05e7 \u05dc\u05d9\u05de\u05d5\u05df",
lightblue:"\u05ea\u05db\u05dc\u05ea",lightcoral:"\u05d0\u05dc\u05de\u05d5\u05d2 \u05d1\u05d4\u05d9\u05e8",lightcyan:"\u05d8\u05d5\u05e8\u05e7\u05d9\u05d6 \u05d1\u05d4\u05d9\u05e8",lightgoldenrodyellow:"\u05e6\u05d4\u05d5\u05d1 \u05d1\u05d4\u05d9\u05e8",lightgray:"\u05d0\u05e4\u05d5\u05e8 \u05d1\u05d4\u05d9\u05e8",lightgreen:"\u05d9\u05e8\u05d5\u05e7 \u05d1\u05d4\u05d9\u05e8",lightgrey:"\u05d0\u05e4\u05d5\u05e8 \u05d1\u05d4\u05d9\u05e8",lightpink:"\u05d5\u05e8\u05d5\u05d3 \u05d1\u05d4\u05d9\u05e8",
lightsalmon:"\u05e1\u05dc\u05de\u05d5\u05df \u05d1\u05d4\u05d9\u05e8",lightseagreen:"\u05d9\u05e8\u05d5\u05e7 \u05d9\u05dd \u05d1\u05d4\u05d9\u05e8",lightskyblue:"\u05db\u05d7\u05d5\u05dc \u05e9\u05de\u05d9\u05d9\u05dd \u05d1\u05d4\u05d9\u05e8",lightslategray:"\u05d0\u05e4\u05d5\u05e8 \u05e6\u05e4\u05d7\u05d4 \u05d1\u05d4\u05d9\u05e8",lightslategrey:"\u05d0\u05e4\u05d5\u05e8 \u05e6\u05e4\u05d7\u05d4 \u05d1\u05d4\u05d9\u05e8",lightsteelblue:"\u05db\u05d7\u05d5\u05dc \u05e4\u05dc\u05d3\u05d4 \u05d1\u05d4\u05d9\u05e8",
lightyellow:"\u05e6\u05d4\u05d5\u05d1 \u05d1\u05d4\u05d9\u05e8",lime:"\u05dc\u05d9\u05de\u05d5\u05df",limegreen:"\u05d9\u05e8\u05d5\u05e7 \u05dc\u05d9\u05de\u05d5\u05e0\u05d9",linen:"\u05e4\u05e9\u05ea\u05df",magenta:"\u05d1\u05d5\u05e8\u05d3\u05d5",maroon:"\u05d7\u05d5\u05dd \u05d0\u05d3\u05de\u05d3\u05dd",mediumaquamarine:"\u05db\u05d7\u05d5\u05dc \u05d1\u05d9\u05e0\u05d5\u05e0\u05d9",mediumblue:"\u05ea\u05db\u05dc\u05ea \u05d1\u05d9\u05e0\u05d5\u05e0\u05d9",mediumorchid:"\u05e1\u05d7\u05dc\u05d1 \u05d1\u05d9\u05e0\u05d5\u05e0\u05d9",
mediumpurple:"\u05e1\u05d2\u05d5\u05dc \u05d1\u05d9\u05e0\u05d5\u05e0\u05d9",mediumseagreen:"\u05d9\u05e8\u05d5\u05e7 \u05d9\u05dd \u05d1\u05d9\u05e0\u05d5\u05e0\u05d9",mediumslateblue:"\u05db\u05d7\u05d5\u05dc \u05e6\u05e4\u05d7\u05d4 \u05d1\u05d9\u05e0\u05d5\u05e0\u05d9",mediumspringgreen:"\u05d9\u05e8\u05d5\u05e7 \u05d0\u05d1\u05d9\u05d1 \u05d1\u05d9\u05e0\u05d5\u05e0\u05d9",mediumturquoise:"\u05d8\u05d5\u05e8\u05e7\u05d9\u05d6 \u05d1\u05d9\u05e0\u05d5\u05e0\u05d9",mediumvioletred:"\u05e1\u05d2\u05d5\u05dc-\u05d0\u05d3\u05d5\u05dd \u05d1\u05d9\u05e0\u05d5\u05e0\u05d9",
midnightblue:"\u05db\u05d7\u05d5\u05dc \u05db\u05d4\u05d4",mintcream:"\u05e7\u05e8\u05dd \u05de\u05e0\u05d8\u05d4",mistyrose:"\u05d5\u05e8\u05d5\u05d3 \u05de\u05e2\u05d5\u05e8\u05e4\u05dc",moccasin:"\u05de\u05d5\u05e7\u05e1\u05d9\u05df",navajowhite:"\u05dc\u05d1\u05df \u05e0\u05d5\u05d5\u05d0\u05d7\u05d5",navy:"\u05db\u05d7\u05d5\u05dc \u05db\u05d4\u05d4",oldlace:"\u05ea\u05d7\u05e8\u05d4 \u05e2\u05ea\u05d9\u05e7\u05d4",olive:"\u05d6\u05d9\u05ea",olivedrab:"\u05d6\u05d9\u05ea \u05e2\u05de\u05d5\u05dd",
orange:"\u05db\u05ea\u05d5\u05dd",orangered:"\u05db\u05ea\u05d5\u05dd \u05d0\u05d3\u05d5\u05dd",orchid:"\u05e1\u05d7\u05dc\u05d1",palegoldenrod:"\u05d6\u05d4\u05d5\u05d1 \u05d1\u05d4\u05d9\u05e8",palegreen:"\u05d9\u05e8\u05d5\u05e7 \u05d1\u05d4\u05d9\u05e8",paleturquoise:"\u05d8\u05d5\u05e8\u05e7\u05d9\u05d6 \u05d1\u05d4\u05d9\u05e8",palevioletred:"\u05e1\u05d2\u05d5\u05dc-\u05d0\u05d3\u05d5\u05dd \u05d1\u05d4\u05d9\u05e8",papayawhip:"\u05e4\u05e4\u05d0\u05d9\u05d4",peachpuff:"\u05e7\u05e6\u05d9\u05e4\u05ea \u05d0\u05e4\u05e8\u05e1\u05e7",
peru:"\u05e4\u05e8\u05d5",pink:"\u05d5\u05e8\u05d5\u05d3",plum:"\u05e9\u05d6\u05d9\u05e3",powderblue:"\u05db\u05d7\u05d5\u05dc \u05d7\u05d9\u05d5\u05d5\u05e8",purple:"\u05e1\u05d2\u05d5\u05dc",red:"\u05d0\u05d3\u05d5\u05dd",rosybrown:"\u05d7\u05d5\u05dd \u05d5\u05e8\u05d3\u05e8\u05d3",royalblue:"\u05db\u05d7\u05d5\u05dc \u05de\u05dc\u05db\u05d5\u05ea\u05d9",saddlebrown:"\u05d7\u05d5\u05dd \u05d3\u05d4\u05d5\u05d9",salmon:"\u05e1\u05dc\u05de\u05d5\u05df",sandybrown:"\u05d7\u05d5\u05dd \u05d7\u05d5\u05dc\u05d9",
seagreen:"\u05d9\u05e8\u05d5\u05e7 \u05d9\u05dd",seashell:"\u05e6\u05d3\u05e3",sienna:"\u05e1\u05d9\u05d9\u05e0\u05d4",silver:"\u05db\u05e1\u05e3",skyblue:"\u05db\u05d7\u05d5\u05dc \u05e9\u05de\u05d9\u05d9\u05dd",slateblue:"\u05db\u05d7\u05d5\u05dc \u05e6\u05e4\u05d7\u05d4",slategray:"\u05d0\u05e4\u05d5\u05e8 \u05e6\u05e4\u05d7\u05d4",slategrey:"\u05d0\u05e4\u05d5\u05e8 \u05e6\u05e4\u05d7\u05d4",snow:"\u05e9\u05dc\u05d2",springgreen:"\u05d9\u05e8\u05d5\u05e7 \u05d0\u05d1\u05d9\u05d1",steelblue:"\u05db\u05d7\u05d5\u05dc \u05e4\u05dc\u05d3\u05d4",
tan:"\u05d7\u05d5\u05dd \u05d0\u05d3\u05de\u05d3\u05dd",teal:"\u05db\u05d7\u05d5\u05dc-\u05d9\u05e8\u05d5\u05e7 \u05db\u05d4\u05d4",thistle:"\u05d3\u05e8\u05d3\u05e8",tomato:"\u05e2\u05d2\u05d1\u05e0\u05d9\u05d4",transparent:"\u05e9\u05e7\u05d5\u05e3",turquoise:"\u05d8\u05d5\u05e8\u05e7\u05d9\u05d6",violet:"\u05e1\u05d2\u05d5\u05dc",wheat:"\u05d7\u05d9\u05d5\u05d8",white:"\u05dc\u05d1\u05df",whitesmoke:"\u05e2\u05e9\u05df \u05dc\u05d1\u05df",yellow:"\u05e6\u05d4\u05d5\u05d1",yellowgreen:"\u05d9\u05e8\u05d5\u05e7 \u05e6\u05d4\u05d5\u05d1",
_localized:{}},"dojox/widget/nls/ColorPicker":{redLabel:"\u05d0",greenLabel:"\u05d9",blueLabel:"\u05db",hueLabel:"\u05d2",saturationLabel:"\u05e8",valueLabel:"\u05e2",degLabel:"\u00b0",hexLabel:"\u05d4\u05e7\u05e1",huePickerTitle:"\u05d1\u05d5\u05e8\u05e8 \u05d2\u05d5\u05d5\u05df",saturationPickerTitle:"\u05d1\u05d5\u05e8\u05e8 \u05e8\u05d5\u05d5\u05d9\u05d4",_localized:{}},"dojox/editor/plugins/nls/TableDialog":{insertTableTitle:"\u05d4\u05d5\u05e1\u05e4\u05ea \u05d8\u05d1\u05dc\u05d4",modifyTableTitle:"\u05e9\u05d9\u05e0\u05d5\u05d9 \u05d8\u05d1\u05dc\u05d4",
rows:"\u05e9\u05d5\u05e8\u05d5\u05ea:",columns:"\u05e2\u05de\u05d5\u05d3\u05d5\u05ea:",align:"\u05d9\u05d9\u05e9\u05d5\u05e8:",cellPadding:"\u05e8\u05d9\u05e4\u05d5\u05d3 \u05ea\u05d0\u05d9\u05dd:",cellSpacing:"\u05e8\u05d9\u05d5\u05d5\u05d7 \u05ea\u05d0\u05d9\u05dd:",tableWidth:"\u05e8\u05d5\u05d7\u05d1 \u05d8\u05d1\u05dc\u05d4:",backgroundColor:"\u05e6\u05d1\u05e2 \u05e8\u05e7\u05e2:",borderColor:"\u05e6\u05d1\u05e2 \u05d2\u05d1\u05d5\u05dc:",borderThickness:"\u05e2\u05d5\u05d1\u05d9 \u05d2\u05d1\u05d5\u05dc:",
percent:"\u05d0\u05d7\u05d5\u05d6",pixels:"\u05e4\u05d9\u05e7\u05e1\u05dc\u05d9\u05dd","default":"\u05d1\u05e8\u05d9\u05e8\u05ea \u05de\u05d7\u05d3\u05dc",left:"\u05d9\u05de\u05d9\u05df",center:"\u05de\u05e8\u05db\u05d6",right:"\u05e9\u05de\u05d0\u05dc",buttonSet:"\u05d4\u05d2\u05d3\u05e8\u05d4",buttonInsert:"\u05d4\u05d5\u05e1\u05e4\u05d4",buttonCancel:"\u05d1\u05d9\u05d8\u05d5\u05dc",selectTableLabel:"\u05d1\u05d7\u05d9\u05e8\u05ea \u05d8\u05d1\u05dc\u05d4",insertTableRowBeforeLabel:"\u05d4\u05d5\u05e1\u05e4\u05ea \u05e9\u05d5\u05e8\u05d4 \u05dc\u05e4\u05e0\u05d9",
insertTableRowAfterLabel:"\u05d4\u05d5\u05e1\u05e4\u05ea \u05e9\u05d5\u05e8\u05d4 \u05d0\u05d7\u05e8\u05d9",insertTableColumnBeforeLabel:"\u05d4\u05d5\u05e1\u05e4\u05ea \u05e2\u05de\u05d5\u05d3\u05d4 \u05dc\u05e4\u05e0\u05d9",insertTableColumnAfterLabel:"\u05d4\u05d5\u05e1\u05e4\u05ea \u05e2\u05de\u05d5\u05d3\u05d4 \u05d0\u05d7\u05e8\u05d9",deleteTableRowLabel:"\u05de\u05d7\u05d9\u05e7\u05ea \u05e9\u05d5\u05e8\u05d4",deleteTableColumnLabel:"\u05de\u05d7\u05d9\u05e7\u05ea \u05e2\u05de\u05d5\u05d3\u05d4",
colorTableCellTitle:"\u05e6\u05d1\u05e2 \u05e8\u05e7\u05e2 \u05e9\u05dc \u05ea\u05d0 \u05d1\u05d8\u05d1\u05dc\u05d4",tableContextMenuTitle:"\u05ea\u05e4\u05e8\u05d9\u05d8 \u05d4\u05e7\u05e9\u05e8 \u05e9\u05dc \u05d8\u05d1\u05dc\u05d4",_localized:{}},"dojox/editor/plugins/nls/PasteFromWord":{pasteFromWord:"\u05d4\u05d3\u05d1\u05e7\u05d4 \u05de\u05ea\u05d5\u05da Word",instructions:"\u05d4\u05d3\u05d1\u05d9\u05e7\u05d5 \u05d0\u05ea \u05d4\u05ea\u05d5\u05db\u05df \u05de\u05ea\u05d5\u05da Word \u05dc\u05ea\u05d5\u05da \u05ea\u05d9\u05d1\u05ea \u05d4\u05ea\u05de\u05dc\u05d9\u05dc \u05dc\u05de\u05d8\u05d4. \u05dc\u05d0\u05d7\u05e8 \u05e9\u05ea\u05d4\u05d9\u05d5 \u05de\u05e8\u05d5\u05e6\u05d9\u05dd \u05de\u05d4\u05ea\u05d5\u05db\u05df \u05dc\u05d4\u05d5\u05e1\u05e4\u05d4, \u05dc\u05d7\u05e6\u05d5 \u05e2\u05dc \u05dc\u05d7\u05e6\u05df \u05d4\u05d4\u05d3\u05d1\u05e7\u05d4. \u05db\u05d3\u05d9 \u05dc\u05d1\u05d8\u05dc \u05d0\u05ea \u05d4\u05d5\u05e1\u05e4\u05ea \u05d4\u05ea\u05de\u05dc\u05d9\u05dc, \u05dc\u05d7\u05e6\u05d5 \u05e2\u05dc \u05dc\u05d7\u05e6\u05df \u05d4\u05d1\u05d9\u05d8\u05d5\u05dc. ",
_localized:{}},"dojox/editor/plugins/nls/InsertAnchor":{insertAnchor:"\u05d4\u05d5\u05e1\u05e4\u05ea \u05e2\u05d5\u05d2\u05df ",title:"\u05ea\u05db\u05d5\u05e0\u05d5\u05ea \u05e2\u05d5\u05d2\u05df ",anchor:"\u05e9\u05dd:",text:"\u05ea\u05d9\u05d0\u05d5\u05e8:",set:"\u05d4\u05d2\u05d3\u05e8\u05d4",cancel:"\u05d1\u05d9\u05d8\u05d5\u05dc",_localized:{}},"dojox/editor/plugins/nls/Blockquote":{blockquote:"\u05e6\u05d9\u05d8\u05d5\u05d8",_localized:{}},"dojox/editor/plugins/nls/LocalImage":{insertImageTitle:"\u05d4\u05d5\u05e1\u05e4\u05ea \u05ea\u05de\u05d5\u05e0\u05d4",
url:"\u05ea\u05de\u05d5\u05e0\u05d4",browse:"\u05e2\u05d9\u05d5\u05df...\u200f ",text:"\u05ea\u05d9\u05d0\u05d5\u05e8 ",set:"\u05d4\u05d5\u05e1\u05e4\u05d4",invalidMessage:"\u05e1\u05d5\u05d2 \u05e7\u05d5\u05d1\u05e5 \u05ea\u05de\u05d5\u05e0\u05d4 \u05dc\u05d0 \u05d7\u05d5\u05e7\u05d9",prePopuTextUrl:"\u05e6\u05d9\u05d9\u05e0\u05d5 URL \u05e9\u05dc \u05ea\u05de\u05d5\u05e0\u05d4",prePopuTextBrowse:" \u05d0\u05d5 \u05e0\u05d5\u05d5\u05d8\u05d5 \u05dc\u05e7\u05d5\u05d1\u05e5 \u05de\u05e7\u05d5\u05de\u05d9. ",
_localized:{}}});
//# sourceMappingURL=pmbdojo_he-il.js.map